@@ -5,15 +5,13 @@
 */
 
 #include "kmlaunchexternalcomponent.h"
+#include "kmail_debug.h"
+#include "newmailnotifierinterface.h"
 #include <Akonadi/AgentConfigurationDialog>
 #include <Akonadi/AgentManager>
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include "archivemailagentinterface.h"
-#include "followupreminderinterface.h"
-#include "mailmergeagentinterface.h"
-#include "sendlateragentinterface.h"
 #include <MailCommon/FilterManager>
 
 #include <KDialogJobUiDelegate>
@@ -47,9 +45,8 @@ void KMLaunchExternalComponent::slotConfigureSendLater()
 {
     auto agent = Akonadi::AgentManager::self()->instance(QStringLiteral("akonadi_sendlater_agent"));
     if (agent.isValid()) {
-        QPointer<Akonadi::AgentConfigurationDialog> dlg = new Akonadi::AgentConfigurationDialog(agent, mParentWidget);
-        dlg->exec();
-        delete dlg;
+        Akonadi::AgentConfigurationDialog dlg(agent, mParentWidget);
+        dlg.exec();
     } else {
         KMessageBox::error(mParentWidget, i18n("Send Later Agent was not registered."));
     }
@@ -59,9 +56,8 @@ void KMLaunchExternalComponent::slotConfigureMailMerge()
 {
     auto agent = Akonadi::AgentManager::self()->instance(QStringLiteral("akonadi_mailmerge_agent"));
     if (agent.isValid()) {
-        QPointer<Akonadi::AgentConfigurationDialog> dlg = new Akonadi::AgentConfigurationDialog(agent, mParentWidget);
-        dlg->exec();
-        delete dlg;
+        Akonadi::AgentConfigurationDialog dlg(agent, mParentWidget);
+        dlg.exec();
     } else {
         KMessageBox::error(mParentWidget, i18n("Mail Merge Agent was not registered."));
     }
@@ -161,3 +157,16 @@ void KMLaunchExternalComponent::slotFilterLogViewer()
 {
     MailCommon::FilterManager::instance()->showFilterLogDialog(static_cast<qlonglong>(mParentWidget->winId()));
 }
+
+void KMLaunchExternalComponent::slotShowNotificationHistory()
+{
+    const auto service = Akonadi::ServerManager::self()->agentServiceName(Akonadi::ServerManager::Agent, QStringLiteral("akonadi_newmailnotifier_agent"));
+    auto newMailNotifierInterface =
+        new OrgFreedesktopAkonadiNewMailNotifierInterface(service, QStringLiteral("/NewMailNotifierAgent"), QDBusConnection::sessionBus(), this);
+    if (!newMailNotifierInterface->isValid()) {
+        qCDebug(KMAIL_LOG) << " org.freedesktop.Akonadi.NewMailNotifierAgent not found. Please verify your installation";
+    } else {
+        newMailNotifierInterface->showNotNotificationHistoryDialog(0); // TODO fix me windid
+    }
+    delete newMailNotifierInterface;
+}
