@@ -10,11 +10,9 @@
 #include "undostack.h"
 
 #include "kmkernel.h"
-#include "kmmainwin.h"
 #include <Akonadi/ItemMoveJob>
 #include <KJob>
 
-#include "kmail_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -100,14 +98,14 @@ void UndoStack::undo()
         delete info;
     } else {
         // Sorry.. stack is empty..
-        KMessageBox::sorry(kmkernel->mainWin(), i18n("There is nothing to undo."));
+        KMessageBox::error(kmkernel->mainWin(), i18n("There is nothing to undo."));
     }
 }
 
 void UndoStack::slotMoveResult(KJob *job)
 {
     if (job->error()) {
-        KMessageBox::sorry(kmkernel->mainWin(), i18n("Cannot move message. %1", job->errorString()));
+        KMessageBox::error(kmkernel->mainWin(), i18n("Cannot move message. %1", job->errorString()));
     }
 }
 
